hotspot/src/share/vm/gc_implementation/g1/g1RemSet.hpp
changeset 6250 5680f968c721
parent 6247 00e5cc407d03
child 6958 cfa71cf3564d
--- a/hotspot/src/share/vm/gc_implementation/g1/g1RemSet.hpp	Wed Aug 04 13:03:23 2010 -0400
+++ b/hotspot/src/share/vm/gc_implementation/g1/g1RemSet.hpp	Fri Aug 06 10:17:21 2010 -0700
@@ -148,10 +148,10 @@
   size_t*             _cards_scanned;
   size_t              _total_cards_scanned;
 
-  // _par_traversal_in_progress is "true" iff a parallel traversal is in
-  // progress.
-  bool _par_traversal_in_progress;
-  void set_par_traversal(bool b) { _par_traversal_in_progress = b; }
+  // _traversal_in_progress is "true" iff a traversal is in progress.
+
+  bool _traversal_in_progress;
+  void set_traversal(bool b) { _traversal_in_progress = b; }
 
   // Used for caching the closure that is responsible for scanning
   // references into the collection set.